@@ -27,17 +27,21 @@ all.equal(b, b1)
 library(sp)
 suppressWarnings(RNGversion("3.5.3"))
 set.seed(1331)
-example(SpatialMultiPoints, ask = FALSE, echo = FALSE) # loads mpdf
+# example(SpatialMultiPoints, ask = FALSE, echo = FALSE) # loads mpdf
+cl1 = cbind(rnorm(3, 10), rnorm(3, 10))
+cl2 = cbind(rnorm(5, 10), rnorm(5,  0))
+cl3 = cbind(rnorm(7,  0), rnorm(7, 10))
+mpdf = SpatialMultiPointsDataFrame(list(cl1, cl2, cl3), data.frame(a = 1:3))
 m = st_as_sf(mpdf)
 all.equal(as(m, "Spatial"), mpdf) # TRUE
 
 demo(meuse, ask = FALSE, echo = FALSE)
-meuse = spTransform(meuse, CRS("+init=epsg:4326"))
+meuse = spTransform(meuse, CRS("+proj=longlat +ellps=WGS84 +no_defs"))
 pol.grd = as(meuse.grid, "SpatialPolygonsDataFrame")
-meuse.grd = spTransform(meuse.grid, CRS("+init=epsg:4326"))
-pol.grd = spTransform(pol.grd, CRS("+init=epsg:4326"))
-meuse.area = spTransform(meuse.area, CRS("+init=epsg:4326"))
-meuse.riv = spTransform(meuse.riv, CRS("+init=epsg:4326"))
+meuse.grd = spTransform(meuse.grid, CRS("+proj=longlat +ellps=WGS84 +no_defs"))
+pol.grd = spTransform(pol.grd, CRS("+proj=longlat +ellps=WGS84 +no_defs"))
+meuse.area = spTransform(meuse.area, CRS("+proj=longlat +ellps=WGS84 +no_defs"))
+meuse.riv = spTransform(meuse.riv, CRS("+proj=longlat +ellps=WGS84 +no_defs"))
 summary(st_as_sf(meuse))
 summary(st_as_sf(meuse.grd))
 x <- st_as_sf(meuse.grid) # don't print: CRS variations.
@@ -47,18 +51,9 @@ summary(st_as_sf(as(meuse.riv, "SpatialLines")))
 summary(st_as_sf(pol.grd))
 summary(st_as_sf(as(pol.grd, "SpatialLinesDataFrame")))
 
-# roundtrip nc: sf -> sp -> sf
-# nc = st_read(system.file("gpkg/nc.gpkg", package="sf"), "nc.gpkg")
-nc = st_read(system.file("shape/nc.shp", package="sf"), "nc", quiet = TRUE)
-p4s = "+proj=longlat +datum=NAD27 +no_defs +ellps=clrk66 +nadgrids=@conus,@alaska,@ntv2_0.gsb,@ntv1_can.dat"
-suppressWarnings(st_crs(nc) <- p4s)
-names(nc)[15] = "geometry"
-attr(nc, "sf_column") = "geometry"
-attr(nc$geometry, "crs")$epsg = NA_integer_
+nc = st_read(system.file("gpkg/nc.gpkg", package="sf"), "nc.gpkg")
 all.equal(nc, st_as_sf(as(nc, "Spatial")))
+st_crs(nc) == st_crs(st_as_sf(as(nc, "Spatial")))
 
-sp = as(nc, "Spatial")
-comment(sp) = "FALSE"
-all.equal(nc, st_as_sf(sp))
 detach("package:sp")
 unloadNamespace("rgeos")
